changeset 21566:1de4d7e69f85

fixed missed renaming
author Doug Simon <doug.simon@oracle.com>
date Fri, 29 May 2015 01:11:41 +0200
parents f5b549811bac
children f41409c6ff26
files mx/mx_graal.py
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/mx/mx_graal.py	Fri May 29 00:35:10 2015 +0200
+++ b/mx/mx_graal.py	Fri May 29 01:11:41 2015 +0200
@@ -1696,8 +1696,8 @@
             buildxml = mx._cygpathU2W(join(_graal_home, 'src', 'share', 'tools', 'IdealGraphVisualizer', 'build.xml'))
             mx.run(['ant', '-f', buildxml, '-q', 'clean', 'build'], env=_igvBuildEnv())
 
-    # Prevent Graal modifications from breaking the standard builds
-    if args.buildNonGraal:
+    # Prevent JVMCI modifications from breaking the standard builds
+    if args.buildNonJVMCI:
         with Task('BuildHotSpotVarieties', tasks) as t:
             if t:
                 buildvms(['--vms', 'client,server', '--builds', 'fastdebug,product'])